..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

====
cast
====

.. automodule:: textops.ops.cast
.. currentmodule:: textops

pretty
------
   .. autoclass:: pretty()

todatetime
----------
   .. autoclass:: todatetime()

todict
------
   .. autoclass:: todict()

tofloat
-------
   .. autoclass:: tofloat()

toint
-----
   .. autoclass:: toint()

tolist
------
   .. autoclass:: tolist(return_if_none=None)

toliste
-------
   .. autoclass:: toliste(return_if_none=[])

tonull
------
   .. autoclass:: tonull()

toslug
------
   .. autoclass:: toslug()

tostr
-----
   .. autoclass:: tostr(join_str='\n', return_if_none=None)

tostre
------
   .. autoclass:: tostre(join_str='\n', return_if_none='')
